ReorderableItem class

guoshijun created this file at 2022/5/5 11:58 上午

子项model

Constructors

ReorderableItem({required int trackingNumber, required String id, required Widget child, int? crossAxisCellCount = 1, int? mainAxisCellCount = 1, Widget? feedback, Widget? placeholder})

Properties

child Widget
getter/setter pair
crossAxisCellCount int?
getter/setter pair
feedback Widget?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
mainAxisCellCount int?
getter/setter pair
placeholder Widget?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingNumber int
getter/setter pair

Methods

changeToValue(ReorderableItem item) → void
compare(ReorderableItem next) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited